@@ -8,9 +8,8 @@ use Carp;
 
 our $VERSION;
 BEGIN {
-    $VERSION = '1.08_1';
+    $VERSION = '1.03';
     our @ISA = qw(DynaLoader);
-    our $_gruntime = 0;
     DynaLoader::bootstrap('JSPL', $VERSION);
 }
 
@@ -67,13 +66,13 @@ sub _boot_ {
     *{$class.'::dl_load_flags'} = DynaLoader->can('dl_load_flags');
     $version ||= $VERSION;
     if(defined &{$class.'::bootstrap'}) {
-	*{"${class}::bootstrap"}->($class, $version);
+	 \&{$class.'::bootstrap'}->($class, $version);
     } else {
 	my $symbol = "boot_$class"; $symbol =~ s/\W/_/g;
 	my $symref = DynaLoader::dl_find_symbol_anywhere($symbol);
 	if($symref) {
 	    DynaLoader::dl_install_xsub($class."::bootstrap", $symref);
-	    *{"${class}::bootstrap"}->($class, $version);
+	    \&{$class."::bootstrap"}->($class, $version);
 	} else {
 	    DynaLoader::bootstrap($class, $version);
 	}
@@ -171,8 +170,7 @@ For details on context creation see L<JSPL::Runtime> and L<JSPL::Context>
 B<Populate the context> with any new functionality your application needs. This
 is done using either the C<bind_*> family of methods from
 L<JSPL::Context> for simple cases or with the L<JSPL::Controller>
-object associated to the context for more complex cases, for example binding Perl 
-classes or entire modules.
+object associated to the context for more complex cases.
 
 =item *
 
@@ -302,7 +300,7 @@ See L<JSPL::Error> for more details
 
 =item C<JavaScript> by Claes Jakobsson
 
-Thought the API are similar, there is a fundamental difference: C<JavaScript>
+Thought the API are similar, there is a fundamental difference: L<JavaScript>
 is mainly a "converter" between types, and this module is a true "reflector",
 so there are a few but important incompatibilities.
 
@@ -428,11 +426,6 @@ C<PL_sv_no>.
 Returns C<PL_sv_yes> if we have compiled support for threading. Otherwise
 returns C<PL_sv_no>.
 
-=item does_support_anonfunfix
-
-Returns C<PL_sv_yes> if we have compiled support for the SM JS_OPTION_ANONFUNFIX.
-Otherwise returns C<PL_sv_no>.
-
 =item does_support_jit
 
 Returns C<PL_sv_yes> if we have compiled support for the SM JIT. Otherwise
@@ -443,10 +436,6 @@ returns C<PL_sv_no>.
 Returns C<PL_sv_yes> if we have compiled support for I<OperationCallbacks> in SM.
 Otherwise returns C<PL_sv_no>
 
-=item exact_doubles
-
-Returns TRUE if the internal size of floating point types matches between Perl and SM.
-
 =item supports ( @features )
 
 Checks if all features given in I<@features> are present. Is case insensitive. Supported keys are 
@@ -481,10 +470,6 @@ See L<CREDITS>
 Although perl 5.8 is supported, it lacks some features and have some bugs, we
 strongly recommends you to use 5.10 or a newer perl.
 
-In environments that support "long doubles", perl can be compiled to use them as
-the default floating point type, but if its size doesn't match SM's jsdouble type,
-you should expect some precision lost.
-
 Please report any bug you found to
 L<https://rt.cpan.org/Public/Dist/Display.html?Name=JSPL>
 
@@ -506,7 +491,7 @@ Miguel Ibarra &lt;mibarra@msg.com.mx&gt;
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2008 - 2012, Salvador Ortiz <sortiz@cpan.org>
+Copyright (c) 2008 - 2010, Salvador Ortiz <sortiz@cpan.org>
 All rights reserved.
 
 Some code adapted from Claes Jakobsson's JavaScript module, 
