@@ -22,19 +22,16 @@ my %Flags = (
     'ConvertRegExp' => 1,
     'Restricted' => 1,
     'ConstantsValue' => 1,
-    'ReflectExceptions' => 1,
     'StrictEnable' => 0,
     'VOFixEnable' => 0,
     'XMLEnable' => 1,
 );
 
-$Flags{AnonFunFixEnable} = 0 if JSPL->does_support_anonfunfix;
 $Flags{JITEnable} = 0 if JSPL->does_support_jit;
 
 sub new {
-    my $pkg = shift;
-    my $runtime = shift;
-    my $self = create($runtime, @_);
+    my ($pkg, $runtime) = @_;
+    my $self = create($runtime);
     my $id = $$self;
     $Contexts{$id} = $self;
     weaken($Contexts{$id});
@@ -42,43 +39,6 @@ sub new {
     return $self;
 }
 
-sub _error_mangler {
-    my $msg = shift;
-    if($msg =~ /\n at -e line 0\n$/) {
-	$msg =~ s/ at -e line 0\n$//;
-    } elsif($msg =~ /at -e line 0/) {
-	my $xpc = $Components::classes{'@mozilla.org/js/xpc/XPConnect;1'}
-	    ->getService($Components::interfaces{'nsIXPConnect'});
-	my $stf = $xpc->CurrentJSStack();
-	$stf->QueryInterface($Components::interfaces{'nsIStackFrame'});
-	my $end = "at " . $stf->filename . " line " . ($stf->lineNumber-1);
-	$msg =~ s/at -e line 0/$end/;
-    }
-    warn($msg);
-}
-
-sub JSPL::_wrapctx {
-    my $ictx = shift;
-    my $prin = shift;
-    my $stock = shift || 'stock';
-    my $rt = bless JSPL::RawRT::create(0), 'JSPL::Runtime';
-    eval "require JSPL::Runtime::\u$stock;"
-	    or croak($@);
-    my $self = $rt->create_context($stock, $ictx, $prin);
-    $self->{"Restricted"} = 0;
-    $Contexts{$$self} = $self; # Unweaken
-    $SIG{__WARN__} = \&_error_mangler;
-    warn("Imported context ready\n");
-}
-
-sub _destroy {
-    my $ctx = shift;
-    croak("Context $ctx not registered\n")
-	unless exists $Contexts{$ctx};
-    $Contexts{$ctx} = undef;
-    delete $Contexts{$ctx};
-}
-
 sub eval {
     my ($self, $source, $name) = @_;
     $name ||= do {
@@ -255,8 +215,6 @@ sub compile_file {
         vofix   => scalar JSPL::_constant('JSOPTION_VAROBJFIX'), 
         xml     => scalar JSPL::_constant('JSOPTION_XML'),
     );
-    $options_by_tag{anonfunfix} = scalar JSPL::_constant('JSOPTION_ANONFUNFIX')
-	if JSPL->does_support_anonfunfix;
     $options_by_tag{jit} = scalar JSPL::_constant('JSOPTION_JIT')
 	if JSPL->does_support_jit;
 
@@ -295,7 +253,6 @@ sub compile_file {
 	my($self, $key, $val) = @_;
 	croak "There isn't a flag '$key' in context\n" unless exists $Flags{$key};
 	if($key =~ /^(.+)Enable/) {
-	    return if $JSPL::_gruntime; # Don't play with foreign context
 	    my $op = lc($1);
 	    my $ops = $self->jsc_get_options;
 	    if($val) { $ops |= $options_by_tag{$op} }
@@ -310,7 +267,6 @@ sub compile_file {
 	my($self, $key) = @_;
 	croak "There isn't a flag '$key' in context\n" unless exists $Flags{$key};
 	if($key =~ /^(.+)Enable/) {
-	    return if $JSPL::_gruntime; # Don't play with foreing context
 	    my $op = lc($1);
 	    my $ops = $self->jsc_get_options;
 	    return $ops & $options_by_tag{$op} ? 1 : 0;
@@ -319,11 +275,6 @@ sub compile_file {
     }
 }
 
-sub JSPL::_this {
-    my $nthis = current->jsvisitor($JSPL::This);
-    $nthis || $JSPL::This;
-}
-
 1;
 __END__
 
@@ -463,7 +414,7 @@ exception is thrown in javascript this method returns C<undef> and C<$@> is set.
 
 =item bind_class ( $jsclass )
 
-Bind a native class created with L<JSPL::PerlClass>
+Bind a native class created L<with JSPL::PerlClass>
 
 =item check_privileges ( )
 
@@ -590,19 +541,6 @@ normal way.
 
 The default value is TRUE
 
-=item ReflectExceptions
-
-When TRUE all I<untrapped> Perl's exceptions (when you C<die> outside an C<eval>)
-in Perl code called from JavaScript land, the exception can be trapped in the 
-caller JavaScript code using C<try .. catch>.
-
-Set it to FALSE and the exception will not be visible in JavaScript code, i.e. the
-exception in untrappable. What happens in the upper Perl's stack depends on the
-value of the C<RaiseExceptions> option. This can be useful when calling untrusted
-JavaScript code.
-
-The default value is TRUE
-
 =item RaiseExceptions
 
 When TRUE all I<untrapped> exceptions in javascript space will raise a perl
