@@ -2,7 +2,6 @@ package JSPL::Controller;
 use strict;
 use warnings;
 our @ISA = qw(JSPL::Object);
-use Scalar::Util();
 use Carp();
 
 sub JSPL::Context::get_controller {
@@ -42,7 +41,6 @@ sub _addtweaks {
     $search =~ s/::/\//g;
     my $tweaks = undef;
     ITER: {
-	local $self->__context->{Restricted} = 0;
 	for my $prefix (@INC) {
 	    $realfilename = "$prefix/JSPL/Tweaks/$search";
 	    if(-f "$realfilename.js") {
@@ -216,7 +214,6 @@ package
 sub _const_sub { # Method call
     my $code = $_[1];
     my $frame = $] > 5.009 ? 1 : 2;
-    JSPL::Context->check_privileges;
     my($package, $file, $line, $hints, $bitmask) = (caller $frame)[0,1,2,8,9];
     # warn sprintf("SBB: $package,$file,$line,'$code', H: %x, BM: %s\n", $hints,$bitmask);
     my $cr = eval join("\n",
@@ -242,22 +239,16 @@ sub toSource {
 
 sub call {
     my $code = $JSPL::This;
-    local $JSPL::This = $_[0];
-    shift unless(Scalar::Util::blessed($_[0]));
+    local $JSPL::This = shift;
     $code->(@_);
 }
 
 sub apply {
+    # FIXME, semantic bug
     my $this = shift;
-    my $arg = shift;
-    if(ref($arg) eq 'HASH') { # Hack arround 'arguments' being an Object
-	$arg = tied(%$arg);
-	my @arg = map JSPL::Array::FETCH($arg, $_), 0 .. $arg->{'length'}-1;
-	$arg = \@arg;
-    }
     my $code = $JSPL::This;
     local $JSPL::This = $this;
-    Scalar::Util::blessed($this) ? $code->($this, @{$arg} ) : $code->(@{$arg});
+    $code->( $this, @{$_[0]} );
 }
 
 package
@@ -366,9 +357,6 @@ JSPL::Controller - Control which Perl namespaces can be used from JavaScript.
 Every context has a controller object. Context's controller object allows you to
 reflect entire perl namespaces to JavaScript side and control how they can be used.
 
-As a "class" in perl are implemented using namespaces, this module allows you to
-reflect perl classes to JavaScript easily.
-
 In the following discussion, we use the words "perl package" or simply "package" to
 refer to a perl namespace, declared in perl with the keyword L<perlfunc/package>.
 
@@ -414,8 +402,8 @@ namespaces visible from JavaScript land. Returns a TRUE value
 returns a FALSE value.
 
 Normal operation is to automatically add namespaces as needed. Packages are
-added when a perl object enters javascript, you use L</install> bellow
-or you use L<JSPL::Context/bind_class> and the package isn't already known.
+added when a perl object enters javacript or you use L<JSPL::Context/bind_class>
+and the package isn't already known.
 
 =item list ( )
     
