@@ -84,7 +84,6 @@ sub __bind_to_stash {
     };
     # warn "Want to bind $self to $sigil${package}::${name}\n";
     no strict 'refs';
-    no warnings 'prototype';
     *{"${package}::${name}"} = $code;
     return 1;
 }
@@ -99,8 +98,7 @@ sub AUTOLOAD {
     goto &JSPL::Context::jsc_call;
 }
 
-package
-    JSPL::XMLObject;
+package JSPL::XMLObject;
 use overload '""' => sub { $_[0]->toXMLString };
 @JSPL::XMLObject::ISA = qw(JSPL::Object);
 
